diff --git a/src/classes/@Blade/Blade.m b/src/classes/@Blade/Blade.m
index e8509d7f588f6ce5828812c203f481a982f2f94f..423c88e1b46e8ff3a25886564bf98df03467f143 100644
--- a/src/classes/@Blade/Blade.m
+++ b/src/classes/@Blade/Blade.m
@@ -19,15 +19,16 @@ classdef Blade < handle
     % -----
     %
     % Blade properties:
     %   nElem - Number of elements, [-]
     %   dy    - Element span, [m]
     %   y     - Element absolute radial position, [m]
     %   r     - Element relative radial position (relative to the total radius), [-]
     %   area  - Element area, [m^2]
     %   chord - Element chord, [m]
     %   twist - Element twist (also called stagger angle), [rad]
     %   iAf   - Index of airfoil to use for each element, [-]
     %   sol   - Element solidity, [-]
     %
     % Blade methods:
     %
@@ -44,7 +45,7 @@ classdef Blade < handle
     %   twist   : Twist of the guide stations, [deg] (same size as rad)
     %   iAf     : Index of the airfoil for the guide stations, [-] (same size as rad)
     %   nElem   : Number of elements to mesh the whole blade, [-]
     %   spinDir : Rotational direction of the current rotor, [-]
     %
     % See also: Rotor, rotare, template, af_tools.Airfoil.
     %
@@ -70,7 +71,7 @@ classdef Blade < handle
         chord (1, :) double {mustBePositive} % Element chord, [m]
         twist (1, :) double {mustBeFinite}   % Element twist (also called stagger angle), [rad]
         iAf (1, :) double {mustBePositive}   % Index of airfoil to use for each element, [-]
-        spinDir (1, 1) % Rotational direction of the current rotor, [-]
+        spinDir (1, 1) = 1 % Rotor spin direction (used for coaxial rotors; 1 = cw, -1 = ccw), [-]
     end
 
     properties (SetAccess = private, Dependent)
@@ -19,15 +19,16 @@ classdef Blade < handle
     %
     % Blade properties:
-    %   nElem - Number of elements, [-]
-    %   dy    - Element span, [m]
-    %   y     - Element absolute radial position, [m]
-    %   r     - Element relative radial position (relative to the total radius), [-]
-    %   area  - Element area, [m^2]
-    %   chord - Element chord, [m]
-    %   twist - Element twist (also called stagger angle), [rad]
-    %   iAf   - Index of airfoil to use for each element, [-]
-    %   sol   - Element solidity, [-]
+    %   nElem   - Number of elements, [-]
+    %   dy      - Element span, [m]
+    %   y       - Element absolute radial position, [m]
+    %   r       - Element relative radial position (relative to the total radius), [-]
+    %   area    - Element area, [m^2]
+    %   chord   - Element chord, [m]
+    %   twist   - Element twist (also called stagger angle), [rad]
+    %   iAf     - Index of airfoil to use for each element, [-]
+    %   sol     - Element solidity, [-]
+    %   spinDir - Rotor spin direction (used for coaxial rotors; 1 = cw, -1 = ccw), [-]
     %
     % Blade methods:
@@ -44,7 +45,7 @@ classdef Blade < handle
     %   iAf     : Index of the airfoil for the guide stations, [-] (same size as rad)
     %   nElem   : Number of elements to mesh the whole blade, [-]
-    %   spinDir : Rotational direction of the current rotor, [-]
+    %   spinDir : Rotor spin direction (used for coaxial rotors; 1 = cw, -1 = ccw), [-]
     %
     % See also: Rotor, rotare, template, af_tools.Airfoil.